searchData={"items":[{"type":"module","title":"Membrane.UDP.Endpoint","doc":"Element that sends buffers received on the input pad over a UDP socket and\nreads packets from a UDP socket and sends their payloads through the output pad.","ref":"Membrane.UDP.Endpoint.html"},{"type":"module","title":"Element options - Membrane.UDP.Endpoint","doc":"Passed via struct `t:Membrane.UDP.Endpoint.t/0`\n\n- `destination_address`  \n\n  ```\n  :inet.ip_address()\n  ```\n  \n  ***Required***  \n  An IP Address that the packets will be sent to.\n\n\n- `destination_port_no`  \n\n  ```\n  :inet.port_number()\n  ```\n  \n  ***Required***  \n  A UDP port number of a target.\n\n\n\n- `local_address`  \n\n  ```\n  :inet.socket_address()\n  ```\n  \n  Default value: `:any`  \n  This address is used in two cases:\n  * An IP Address set for a UDP socket used to sent packets.\n  * An IP Address on which the socket will listen.\n  In both cases, it allows to choose which network interface to use if there's more than one.\n\n\n\n- `local_port_no`  \n\n  ```\n  :inet.port_number()\n  ```\n  \n  Default value: `0`  \n  A UDP port number used when opening a receiving socket and for sending packets.\n\n\n\n- `recv_buffer_size`  \n\n  ```\n  pos_integer()\n  ```\n  \n  Default value: `1048576`  \n  Size of the receive buffer. Packages of size greater than this buffer will be truncated","ref":"Membrane.UDP.Endpoint.html#module-element-options"},{"type":"module","title":"Pads - Membrane.UDP.Endpoint","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\n\n\n### `:output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:push`","ref":"Membrane.UDP.Endpoint.html#module-pads"},{"type":"function","title":"Membrane.UDP.Endpoint.options/0","doc":"Returns description of options available for this module","ref":"Membrane.UDP.Endpoint.html#options/0"},{"type":"type","title":"Membrane.UDP.Endpoint.t/0","doc":"Struct containing options for `Membrane.UDP.Endpoint`","ref":"Membrane.UDP.Endpoint.html#t:t/0"},{"type":"module","title":"Membrane.UDP.Sink","doc":"Element that sends buffers received on the input pad over a UDP socket.","ref":"Membrane.UDP.Sink.html"},{"type":"module","title":"Element options - Membrane.UDP.Sink","doc":"Passed via struct `t:Membrane.UDP.Sink.t/0`\n\n- `destination_address`  \n\n  ```\n  :inet.ip_address()\n  ```\n  \n  ***Required***  \n  An IP Address that the packets will be sent to.\n\n\n- `destination_port_no`  \n\n  ```\n  :inet.port_number()\n  ```\n  \n  ***Required***  \n  A UDP port number of a target.\n\n\n\n- `local_address`  \n\n  ```\n  :inet.socket_address()\n  ```\n  \n  Default value: `:any`  \n  An IP Address set for a UDP socket used to sent packets. It allows to specify which\n  network interface to use if there's more than one.\n\n\n\n- `local_port_no`  \n\n  ```\n  :inet.port_number()\n  ```\n  \n  Default value: `0`  \n  A UDP port number for the socket used to sent packets. If set to `0` (default)\n  the underlying OS will assign a free UDP port.\n\n\n\n- `local_socket`  \n\n  ```\n  :gen_udp.socket() | nil\n  ```\n  \n  Default value: `nil`  \n  Already opened UDP socket, if provided it will be used instead of creating\n  and opening a new one.","ref":"Membrane.UDP.Sink.html#module-element-options"},{"type":"module","title":"Pads - Membrane.UDP.Sink","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`","ref":"Membrane.UDP.Sink.html#module-pads"},{"type":"function","title":"Membrane.UDP.Sink.options/0","doc":"Returns description of options available for this module","ref":"Membrane.UDP.Sink.html#options/0"},{"type":"type","title":"Membrane.UDP.Sink.t/0","doc":"Struct containing options for `Membrane.UDP.Sink`","ref":"Membrane.UDP.Sink.html#t:t/0"},{"type":"module","title":"Membrane.UDP.Source","doc":"Element that reads packets from a UDP socket and sends their payloads through the output pad.\n\nBy receiving a `:close_socket` notification this element will close the socket and send\n`end_of_stream` to it's output pad.","ref":"Membrane.UDP.Source.html"},{"type":"module","title":"Element options - Membrane.UDP.Source","doc":"Passed via struct `t:Membrane.UDP.Source.t/0`\n\n- `local_port_no`  \n\n  ```\n  pos_integer()\n  ```\n  \n  Default value: `5000`  \n  A UDP port number used when opening a receiving socket.\n\n\n- `local_address`  \n\n  ```\n  :inet.socket_address()\n  ```\n  \n  Default value: `:any`  \n  An IP Address on which the socket will listen. It allows to choose which\n  network interface to use if there's more than one.\n\n\n\n- `recv_buffer_size`  \n\n  ```\n  pos_integer()\n  ```\n  \n  Default value: `1048576`  \n  Size of the receive buffer. Packages of size greater than this buffer will be truncated\n\n\n\n- `pierce_nat_ctx`  \n\n  ```\n  %{uri: URI.t(), address: :inet.ip_address(), port: pos_integer()} | nil\n  ```\n  \n  Default value: `nil`  \n  Context necessary to make an attempt to create client-side NAT binding\n  by sending an empty datagram from the `Membrane.UDP.Source` to an arbitrary host.\n  \n  * If left as `nil`, no attempt will ever be made.\n  * If filled in, whenever the pipeline switches playback to `:playing`,\n  one datagram (with an empty payload) will be sent from the opened socket\n  to the `:port` at `:address` provided via this option.\n  If `:address` is not present, it will be parsed from `:uri`.\n  \n  Disclaimer: This is a potential vulnerability. Use with caution.","ref":"Membrane.UDP.Source.html#module-element-options"},{"type":"module","title":"Pads - Membrane.UDP.Source","doc":"### `:output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:push`","ref":"Membrane.UDP.Source.html#module-pads"},{"type":"function","title":"Membrane.UDP.Source.options/0","doc":"Returns description of options available for this module","ref":"Membrane.UDP.Source.html#options/0"},{"type":"type","title":"Membrane.UDP.Source.t/0","doc":"Struct containing options for `Membrane.UDP.Source`","ref":"Membrane.UDP.Source.html#t:t/0"},{"type":"extras","title":"Membrane UDP plugin","doc":"# Membrane UDP plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_udp_plugin.svg)](https://hex.pm/packages/membrane_udp_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_udp_plugin/)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_udp_plugin.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_udp_plugin)\n\nThis package provides UDP Source and Sink, that read and write to UDP sockets.","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane UDP plugin","doc":"Add the following line to your `deps` in `mix.exs`. Run `mix deps.get`.\n\n```elixir\n\t{:membrane_udp_plugin, \"~> 0.14.0\"}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage example - Membrane UDP plugin","doc":"The `example/` folder contains examples of sending and receiving UDP streams.\n\nThe `UDPDemo.Receive` retrieves packets from UDP socket and saves the data to the `/tmp/udp-recv.mp4` file.\n```bash\n$ elixir examples/receive.exs\n```\n\nThe `UDPDemo.Send` downloads an example file over HTTP and sends it over UDP socket via localhost:5001.\nIt should be started after the receiver server is already running.\n```bash\n$ elixir examples/send.exs\n```\n\nBear in mind that for other files/sending pipelines you may need do adjust\n[`recv_buffer_size`](https://hexdocs.pm/membrane_udp_plugin/Membrane.UDP.Source.html#module-element-options)\noption in `Membrane.UDP.Source` that determines the maximum size of received packets.","ref":"readme.html#usage-example"},{"type":"extras","title":"Copyright and License - Membrane UDP plugin","doc":"Copyright 2024, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"License","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2018 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}